@@ -13,9 +13,9 @@
  * @brief         http://www.iptc.org/std/Iptc4xmpCore/1.0/specification/Iptc4xmpCore_1.0-spec-XMPSchema_8.pdf
  * @brief  Paper: http://www.metadataworkinggroup.com/pdf/mwg_guidance.pdf
  *
- * @author Copyright (C) 2006-2012 by Gilles Caulier
+ * @author Copyright (C) 2006-2013 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
- * @author Copyright (C) 2006-2012 by Marcel Wiesweg
+ * @author Copyright (C) 2006-2013 by Marcel Wiesweg
  *         <a href="mailto:marcel dot wiesweg at gmx dot de">marcel dot wiesweg at gmx dot de</a>
  *
  * This program is free software; you can redistribute it
@@ -106,6 +106,18 @@ public:
         ORIENTATION_ROT_270      = 8
     };
 
+    /**
+     * Xmp tag types, used by setXmpTag, only first three types are used
+     */
+    enum XmpTagType
+    {
+        NormalTag               = 0,
+        ArrayBagTag             = 1,
+        StructureTag            = 2,
+        ArrayLangTag            = 3,
+        ArraySeqTag             = 4
+    };
+
     /** A map used to store Tags Key and Tags Value.
      */
     typedef QMap<QString, QString> MetaDataMap;
@@ -578,6 +590,8 @@ public:
         "Image"
         "Photo"
 
+        List can be empty to not filter output.
+
         ... this method will return a map of all Exif tags witch :
 
         - include "Iop", or "Thumbnail", or "Image", or "Photo" in the Exif tag keys
@@ -585,7 +599,7 @@ public:
         - not include "Iop", or "Thumbnail", or "Image", or "Photo" in the Exif tag keys
           if 'inverSelection' is true.
      */
-    KExiv2::MetaDataMap getExifTagsDataList(const QStringList& exifKeysFilter, bool invertSelection=false) const;
+    KExiv2::MetaDataMap getExifTagsDataList(const QStringList& exifKeysFilter=QStringList(), bool invertSelection=false) const;
 
     //@}
 
@@ -676,6 +690,8 @@ public:
         "Envelope"
         "Application2"
 
+        List can be empty to not filter output.
+
         ... this method will return a map of all Iptc tags witch :
 
         - include "Envelope", or "Application2" in the Iptc tag keys
@@ -683,7 +699,7 @@ public:
         - not include "Envelope", or "Application2" in the Iptc tag keys
           if 'inverSelection' is true.
      */
-    KExiv2::MetaDataMap getIptcTagsDataList(const QStringList& iptcKeysFilter, bool invertSelection=false) const;
+    KExiv2::MetaDataMap getIptcTagsDataList(const QStringList& iptcKeysFilter=QStringList(), bool invertSelection=false) const;
 
     /** Return a strings list of Iptc keywords from image. Return an empty list if no keyword are set.
      */
@@ -761,7 +777,15 @@ public:
 
     /** Set a Xmp tag content using a string. Return true if tag is set successfully.
      */
-    bool setXmpTagString(const char* xmpTagName, const QString& value, bool setProgramName=true) const;
+    bool setXmpTagString(const char* xmpTagName, const QString& value,
+                         bool setProgramName=true) const;
+
+    /** Set a Xmp tag with a specific type. Return true if tag is set successfully.
+     *  This method only accept NormalTag, ArrayBagTag and StructureTag.
+     *  Other XmpTagTypes do nothing
+     */
+    bool setXmpTagString(const char* xmpTagName, const QString& value,
+                         XmpTagType type,bool setProgramName=true) const;
 
     /** Return the Xmp Tag title or a null string.
      */
@@ -780,6 +804,8 @@ public:
         "dc"           // Dubling Core schema.
         "xmp"          // Standard Xmp schema.
 
+        List can be empty to not filter output.
+
         ... this method will return a map of all Xmp tags witch :
 
         - include "dc", or "xmp" in the Xmp tag keys
@@ -787,7 +813,7 @@ public:
         - not include "dc", or "xmp" in the Xmp tag keys
           if 'inverSelection' is true.
      */
-    KExiv2::MetaDataMap getXmpTagsDataList(const QStringList& xmpKeysFilter, bool invertSelection=false) const;
+    KExiv2::MetaDataMap getXmpTagsDataList(const QStringList& xmpKeysFilter=QStringList(), bool invertSelection=false) const;
 
     /** Get all redondant Alternative Language Xmp tags content like a map.
         See AltLangMap class description for details.
